Coverage for /root/GitHubProjects/impacket/impacket/pcap_linktypes.py: 100%

# Coverage for /root/GitHubProjects/impacket/impacket/pcap_linktypes.py : 100%

## 164 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# SECUREAUTH LABS. Copyright 2018 SecureAuth Corporation. All rights reserved.

2#

3# This software is provided under under a slightly modified version

4# of the Apache Software License. See the accompanying LICENSE file

5# for more information.

6#

7

8 LINKTYPE_NULL = 0

9 DLT_NULL = LINKTYPE_NULL

10 LINKTYPE_ETHERNET = 1

11 DLT_EN10MB = LINKTYPE_ETHERNET

12 LINKTYPE_AX25 = 3

13 DLT_AX25 = LINKTYPE_AX25

14 NKTYPE_IEEE802_5 = 6

15 DLT_IEEE802 = NKTYPE_IEEE802_5

16 LINKTYPE_ARCNET_BSD = 7

17 DLT_ARCNET = LINKTYPE_ARCNET_BSD

18 LINKTYPE_SLIP = 8

19 DLT_SLIP = LINKTYPE_SLIP

20 LINKTYPE_PPP = 9

21 DLT_PPP = LINKTYPE_PPP

22 LINKTYPE_FDDI = 10

23 DLT_FDDI = LINKTYPE_FDDI

24 LINKTYPE_PPP_HDLC = 50

25 DLT_PPP_SERIAL = LINKTYPE_PPP_HDLC

26 LINKTYPE_PPP_ETHER = 51

27 DLT_PPP_ETHER = LINKTYPE_PPP_ETHER

28 LINKTYPE_ATM_RFC1483 = 100

29 DLT_ATM_RFC1483 = LINKTYPE_ATM_RFC1483

30 LINKTYPE_RAW = 101

31 DLT_RAW = LINKTYPE_RAW

32 LINKTYPE_C_HDLC = 104

33 DLT_C_HDLC = LINKTYPE_C_HDLC

34 LINKTYPE_IEEE802_11 = 105

35 DLT_IEEE802_11 = LINKTYPE_IEEE802_11

36 LINKTYPE_FRELAY = 107

37 DLT_FRELAY = LINKTYPE_FRELAY

38 LINKTYPE_LOOP = 108

39 DLT_LOOP = LINKTYPE_LOOP

40 LINKTYPE_LINUX_SLL = 113

41 DLT_LINUX_SLL = LINKTYPE_LINUX_SLL

42 LINKTYPE_LTALK = 114

43 DLT_LTALK = LINKTYPE_LTALK

44 LINKTYPE_PFLOG = 117

45 DLT_PFLOG = LINKTYPE_PFLOG

46 LINKTYPE_IEEE802_11_PRISM = 119

47 DLT_PRISM_HEADER = LINKTYPE_IEEE802_11_PRISM

48 LINKTYPE_IP_OVER_FC = 122

49 DLT_IP_OVER_FC = LINKTYPE_IP_OVER_FC

50 LINKTYPE_SUNATM = 123

51 DLT_SUNATM = LINKTYPE_SUNATM

52 LINKTYPE_IEEE802_11_RADIOTAP = 127

53 DLT_IEEE802_11_RADIO = LINKTYPE_IEEE802_11_RADIOTAP

54 LINKTYPE_ARCNET_LINUX = 129

55 DLT_ARCNET_LINUX = LINKTYPE_ARCNET_LINUX

56 LINKTYPE_APPLE_IP_OVER_IEEE1394 = 138

57 DLT_APPLE_IP_OVER_IEEE1394 = LINKTYPE_APPLE_IP_OVER_IEEE1394

58 LINKTYPE_MTP2_WITH_PHDR = 139

59 DLT_MTP2_WITH_PHDR = LINKTYPE_MTP2_WITH_PHDR

60 LINKTYPE_MTP2 = 140

61 DLT_MTP2 = LINKTYPE_MTP2

62 LINKTYPE_MTP3 = 141

63 DLT_MTP3 = LINKTYPE_MTP3

64 LINKTYPE_SCCP = 142

65 DLT_SCCP = LINKTYPE_SCCP

66 LINKTYPE_DOCSIS = 143

67 DLT_DOCSIS = LINKTYPE_DOCSIS

68 LINKTYPE_LINUX_IRDA = 144

69 DLT_LINUX_IRDA = LINKTYPE_LINUX_IRDA

70 LINKTYPE_IEEE802_11_AVS = 163

71 DLT_IEEE802_11_RADIO_AVS = LINKTYPE_IEEE802_11_AVS

72 LINKTYPE_BACNET_MS_TP = 165

73 DLT_BACNET_MS_TP = LINKTYPE_BACNET_MS_TP

74 LINKTYPE_PPP_PPPD = 166

75 DLT_PPP_PPPD = LINKTYPE_PPP_PPPD

76 LINKTYPE_GPRS_LLC = 169

77 DLT_GPRS_LLC = LINKTYPE_GPRS_LLC

78 LINKTYPE_LINUX_LAPD = 177

79 DLT_LINUX_LAPD = LINKTYPE_LINUX_LAPD

80 LINKTYPE_BLUETOOTH_HCI_H4 = 187

81 DLT_BLUETOOTH_HCI_H4 = LINKTYPE_BLUETOOTH_HCI_H4

82 LINKTYPE_USB_LINUX = 189

83 DLT_USB_LINUX = LINKTYPE_USB_LINUX

84 LINKTYPE_PPI = 192

85 DLT_PPI = LINKTYPE_PPI

86 LINKTYPE_IEEE802_15_4 = 195

87 DLT_IEEE802_15_4 = LINKTYPE_IEEE802_15_4

88 LINKTYPE_SITA = 196

89 DLT_SITA = LINKTYPE_SITA

90 LINKTYPE_ERF = 197

91 DLT_ERF = LINKTYPE_ERF

92 LINKTYPE_BLUETOOTH_HCI_H4_WITH_PHDR = 201

93 DLT_BLUETOOTH_HCI_H4_WITH_PHDR = LINKTYPE_BLUETOOTH_HCI_H4_WITH_PHDR

94 LINKTYPE_AX25_KISS = 202

95 DLT_AX25_KISS = LINKTYPE_AX25_KISS

96 LINKTYPE_LAPD = 203

97 DLT_LAPD = LINKTYPE_LAPD

98 LINKTYPE_PPP_WITH_DIR = 204

99 DLT_PPP_WITH_DIR = LINKTYPE_PPP_WITH_DIR

100 LINKTYPE_C_HDLC_WITH_DIR = 205

101 DLT_C_HDLC_WITH_DIR = LINKTYPE_C_HDLC_WITH_DIR

102 LINKTYPE_FRELAY_WITH_DIR = 206

103 DLT_FRELAY_WITH_DIR = LINKTYPE_FRELAY_WITH_DIR

104 LINKTYPE_IPMB_LINUX = 209

105 DLT_IPMB_LINUX = LINKTYPE_IPMB_LINUX

106 LINKTYPE_IEEE802_15_4_NONASK_PHY = 215

107 DLT_IEEE802_15_4_NONASK_PHY = LINKTYPE_IEEE802_15_4_NONASK_PHY

108 LINKTYPE_USB_LINUX_MMAPPED = 220

109 DLT_USB_LINUX_MMAPPED = LINKTYPE_USB_LINUX_MMAPPED

110 LINKTYPE_FC_2 = 224

111 DLT_FC_2 = LINKTYPE_FC_2

112 LINKTYPE_FC_2_WITH_FRAME_DELIMS = 225

113 DLT_FC_2_WITH_FRAME_DELIMS = LINKTYPE_FC_2_WITH_FRAME_DELIMS

114 LINKTYPE_IPNET = 226

115 DLT_IPNET = LINKTYPE_IPNET

116 LINKTYPE_CAN_SOCKETCAN = 227

117 DLT_CAN_SOCKETCAN = LINKTYPE_CAN_SOCKETCAN

118 LINKTYPE_IPV4 = 228

119 DLT_IPV4 = LINKTYPE_IPV4

120 LINKTYPE_IPV6 = 229

121 DLT_IPV6 = LINKTYPE_IPV6

122 LINKTYPE_IEEE802_15_4_NOFCS = 230

123 DLT_IEEE802_15_4_NOFCS = LINKTYPE_IEEE802_15_4_NOFCS

124 LINKTYPE_DBUS = 231

125 DLT_DBUS = LINKTYPE_DBUS

126 LINKTYPE_DVB_CI = 235

127 DLT_DVB_CI = LINKTYPE_DVB_CI

128 LINKTYPE_MUX27010 = 236

129 DLT_MUX27010 = LINKTYPE_MUX27010

130 LINKTYPE_STANAG_5066_D_PDU = 237

131 DLT_STANAG_5066_D_PDU = LINKTYPE_STANAG_5066_D_PDU

132 LINKTYPE_NFLOG = 239

133 DLT_NFLOG = LINKTYPE_NFLOG

134 LINKTYPE_NETANALYZER = 240

135 DLT_NETANALYZER = LINKTYPE_NETANALYZER

136 LINKTYPE_NETANALYZER_TRANSPARENT = 241

137 DLT_NETANALYZER_TRANSPARENT = LINKTYPE_NETANALYZER_TRANSPARENT

138 LINKTYPE_IPOIB = 242

139 DLT_IPOIB = LINKTYPE_IPOIB

140 LINKTYPE_MPEG_2_TS = 243

141 DLT_MPEG_2_TS = LINKTYPE_MPEG_2_TS

142 LINKTYPE_NG40 = 244

143 DLT_NG40 = LINKTYPE_NG40

144 LINKTYPE_NFC_LLCP = 245

145 DLT_NFC_LLCP = LINKTYPE_NFC_LLCP

146 LINKTYPE_INFINIBAND = 247

147 DLT_INFINIBAND = LINKTYPE_INFINIBAND

148 LINKTYPE_SCTP = 248

149 DLT_SCTP = LINKTYPE_SCTP

150 LINKTYPE_USBPCAP = 249

151 DLT_USBPCAP = LINKTYPE_USBPCAP

152 LINKTYPE_RTAC_SERIAL = 250

153 DLT_RTAC_SERIAL = LINKTYPE_RTAC_SERIAL

154 LINKTYPE_BLUETOOTH_LE_LL = 251

155 DLT_BLUETOOTH_LE_LL = LINKTYPE_BLUETOOTH_LE_LL

156 LINKTYPE_NETLINK = 253

157 DLT_NETLINK = LINKTYPE_NETLINK

158 LINKTYPE_BLUETOOTH_LINUX_MONITOR = 254

159 DLT_BLUETOOTH_LINUX_MONITOR = LINKTYPE_BLUETOOTH_LINUX_MONITOR

160 LINKTYPE_BLUETOOTH_BREDR_BB = 255

161 DLT_BLUETOOTH_BREDR_BB = LINKTYPE_BLUETOOTH_BREDR_BB

162 LINKTYPE_BLUETOOTH_LE_LL_WITH_PHDR = 256

163 DLT_BLUETOOTH_LE_LL_WITH_PHDR = LINKTYPE_BLUETOOTH_LE_LL_WITH_PHDR

164 LINKTYPE_PROFIBUS_DL = 257

165 DLT_PROFIBUS_DL = LINKTYPE_PROFIBUS_DL

166 LINKTYPE_PKTAP = 258

167 DLT_PKTAP = LINKTYPE_PKTAP

168 LINKTYPE_EPON = 259

169 DLT_EPON = LINKTYPE_EPON

170 LINKTYPE_IPMI_HPM_2 = 260

171 DLT_IPMI_HPM_2 = LINKTYPE_IPMI_HPM_2